#!/usr/bin/env python
# -*- coding: utf-8 -*-

import re
from typing import Optional, Any
import scrapy

from collector.items import SensitiveWordItem
from web.manager.log_manager import LogManager
from web.spider.base_spider import BaseSpider
from web.util.re_util import ReUtil

Logger = LogManager.get_logger(__name__)


class CollectorSpider(scrapy.Spider, BaseSpider):
    """
    从微博上爬数据
    """

    name = "collector-spider"
    allowed_domains = ["s.weibo.com"]
    # start_urls = ["https://s.weibo.com/weibo?q=%E5%8C%97%E4%BA%AC%E5%B7%A5%E5%95%86%E5%A4%A7%E5%AD%A6&nodup=1&page=5"]
    start_urls = ["https://xm.buyiju.com/ceming/129803-zajo.html"]
    # url = 'https://xm.buyiju.com/ceming/129803-zajo.html'

    def __init__(self, name: Optional[str] = None, **kwargs: Any):
        scrapy.Spider.__init__(self)
        BaseSpider.__init__(self)

    # def start_requests(self):
    #     yield scrapy.Request(url=self.url, callback=self.parse)

    def parse(self, response):

        Logger.info('从微博上爬数据')
        # 返回的html
        text = response.text

        # 查询敏感词，并将其拼接为字符串，用|分隔
        training_sensitive_word_list = self.training_sensitive_word_service.find_all()
        temp_training_sensitive_word_list = list(map(lambda training_sensitive_word: str(training_sensitive_word.word), training_sensitive_word_list))
        match_str = '.+|.+'.join(temp_training_sensitive_word_list)

        # 去除返回值中的html标签
        text_without_html = ReUtil.clear_html(text)
        text_without_html_list = text_without_html.split('\n')

        # 匹配
        is_match = False
        sensitive_word_item = SensitiveWordItem()
        for item in text_without_html_list:
            match = re.match(match_str, item)
            if match:
                sensitive_word_item['sensitive_word'] = match.group()
                is_match = True
                break
        if is_match:
            yield sensitive_word_item
